const React = require('react')
const PropTypes = require('prop-types')
const addons = require('@storybook/addons').default
const createReactClass = require('create-react-class')
const {
  ADDON_ID,
  PANEL_ID,
  EVENT_ID,
} = require('./shared')

const FigmaPanel = createReactClass({
  initialState: {
    embedHost: 'storybook',
    url: null,
    allowFullScreen: true,
  },
  propTypes: {
    channel: PropTypes.object,
    api: PropTypes.object,
  },
  getDefaultProps: function() {
    return {
      channel: {},
      api: {},
    };
  },

  // constructor(...args) {
  //   super(...args)
  //   this.state = {
  //     ...FigmaPanel.initialState,
  //   }
  //   this.onAddFigma = this.onAddFigma.bind(this)
  // }

  getInitialState: function() {
    return {
      ...this.initialState,
    }
  },

  componentDidMount: function() {
    const { channel, api } = this.props
    channel.on(EVENT_ID, this.onAddFigma)

    this.stopListeningOnStory = api.onStory(() => {
      this.onAddFigma({ ...FigmaPanel.initialState })
    })
  },

  componentWillUnmount: function() {
    if (this.stopListeningOnStory) {
      this.stopListeningOnStory()
    }

    this.unmounted = true
    const { channel } = this.props
    channel.removeListener(EVENT_ID, this.onAddFigma)
  },

  onAddFigma: function({
    url,
    embedHost=this.initialState.embedHost,
    allowFullScreen=this.initialState.allowFullScreen,
  }) {
    this.setState({
      url,
      embedHost,
      allowFullScreen,
    })
  },

  render: function() {
    const {
      url,
      allowFullScreen,
      embedHost,
    } = this.state

    if (!url) {
      return (
        <div
          style={{
            margin: '1rem',
            fontFamily: 'Arial',
            fontSize: '1rem',
            color: '#444',
            width: '100%',
            overflow: 'auto',
          }}
        >
          <strong>Oh Hey! 👋 Add a Figma design to your story:</strong>
          <pre>
          {`
          import React from 'react'
          import { storiesOf } from '@storybook/react'
          import { WithFigma } from 'storybook-addon-figma'

          storiesOf('Button', module)
            .add('default', () => (
              <WithFigma
                url={'https://www.figma.com/file/LKQ4FJ4bTnCSjedbRpk931/Sample-File'}
              >
                <button>Hello</button>
              </WithFigma>
            ))`}
          </pre>
        </div>
      )
    }
    return (
      <iframe
        height="100%"
        width="100%"
        frameBorder="0"
        src={`https://www.figma.com/embed?embed_host=${embedHost}&url=${url}`}
        allowFullScreen={allowFullScreen}
      />
    )
  }
});

// class FigmaPanel extends React.Component {
//   static initialState = {
//     embedHost: 'storybook',
//     url: null,
//     allowFullScreen: true,
//   }
//   static propTypes = {
//     channel: PropTypes.object,
//     api: PropTypes.object,
//   }
//   static defaultProps = {
//     channel: {},
//     api: {},
//   }
//
//   constructor(...args) {
//     super(...args)
//     this.state = {
//       ...FigmaPanel.initialState,
//     }
//     this.onAddFigma = this.onAddFigma.bind(this)
//   }
//
//   componentDidMount() {
//     const { channel, api } = this.props
//     channel.on(EVENT_ID, this.onAddFigma)
//
//     this.stopListeningOnStory = api.onStory(() => {
//       this.onAddFigma({ ...FigmaPanel.initialState })
//     })
//   }
//
//   componentWillUnmount() {
//     if (this.stopListeningOnStory) {
//       this.stopListeningOnStory()
//     }
//
//     this.unmounted = true
//     const { channel } = this.props
//     channel.removeListener(EVENT_ID, this.onAddFigma)
//   }
//
//   onAddFigma({
//     url,
//     embedHost=FigmaPanel.initialState.embedHost,
//     allowFullScreen=FigmaPanel.initialState.allowFullScreen,
//   }) {
//     this.setState({
//       url,
//       embedHost,
//       allowFullScreen,
//     })
//   }
//
//   render() {
//     const {
//       url,
//       allowFullScreen,
//       embedHost,
//     } = this.state
//
//     if (!url) {
//       return (
//         <div
//           style={{
//             margin: '1rem',
//             fontFamily: 'Arial',
//             fontSize: '1rem',
//             color: '#444',
//             width: '100%',
//             overflow: 'auto',
//           }}
//         >
//           <strong>Oh Hey! 👋 Add a Figma design to your story:</strong>
//           <pre>
//           {`
//           import React from 'react'
//           import { storiesOf } from '@storybook/react'
//           import { WithFigma } from 'storybook-addon-figma'
//
//           storiesOf('Button', module)
//             .add('default', () => (
//               <WithFigma
//                 url={'https://www.figma.com/file/LKQ4FJ4bTnCSjedbRpk931/Sample-File'}
//               >
//                 <button>Hello</button>
//               </WithFigma>
//             ))`}
//           </pre>
//         </div>
//       )
//     }
//     return (
//       <iframe
//         height="100%"
//         width="100%"
//         frameBorder="0"
//         src={`https://www.figma.com/embed?embed_host=${embedHost}&url=${url}`}
//         allowFullScreen={allowFullScreen}
//       />
//     )
//   }
// }

addons.register(ADDON_ID, api => {
  addons.addPanel(PANEL_ID, {
    title: 'Figma',
    render: () => <FigmaPanel channel={addons.getChannel()} api={api} />,
  })
})
